@@ -175,7 +175,7 @@ fuzzable_names = [
     "password",
     "lock",
     "find",
-    "alloc",
+    "allocate",
     "peer",
     "block",
     "socket",
@@ -287,10 +287,8 @@ fuzzable_names += [
     "wrote",
     "reduce",
     "advance",
-    "mix",
     "describe",
     "produce",
-    "plac",
     "operate",
     "surge",
     "jump",
@@ -420,7 +418,7 @@ fuzzable_names += [
     "warn",
     "qualifi",
     "explain",
-    "impos",
+    "impose",
     "recognize",
     "indicate",
     "point",
@@ -436,9 +434,9 @@ fuzzable_names += [
     "remove",
     "revive",
     "predict",
-    "coupl",
+    "couple",
     "play",
-    "committ",
+    "commit",
     "revive",
     "kill",
     "present",
@@ -463,12 +461,12 @@ fuzzable_names += [
     "contact",
     "print",
     "advertise",
-    "damag",
+    "damage",
     "exercis",
     "auction",
     "disappoint",
     "subordinat",
-    "secur",
+    "secure",
     "integrat",
     "perform",
     "stepp",
@@ -488,11 +486,10 @@ fuzzable_names += [
     "support",
     "abandon",
     "figure",
-    "edg",
     "extend",
     "tender",
     "unveil",
-    "expos",
+    "expose",
     "industrializ",
     "regulate",
     "contract",
@@ -502,7 +499,6 @@ fuzzable_names += [
     "prolong",
     "record",
     "announce",
-    "bow",
     "assert",
     "inch",
     "manufacture",
@@ -511,12 +507,10 @@ fuzzable_names += [
     "favor",
     "train",
     "institut",
-    "vow",
-    "deem",
     "concern",
     "accelerat",
-    "solv",
-    "stor",
+    "solve",
+    "store",
     "assembl",
     "link",
     "advertis",
@@ -533,13 +527,13 @@ fuzzable_names += [
     "endors",
     "balk",
     "compensate",
-    "terminat",
-    "operat",
+    "terminate",
+    "operate",
     "admit",
     "attract",
-    "featur",
+    "feature",
     "devote",
-    "tripl",
+    "triple",
     "concentrat",
     "plead",
     "inspir",
@@ -550,14 +544,13 @@ fuzzable_names += [
     "surfac",
     "concentrate",
     "suffer",
-    "lov",
     "advis",
     "interview",
     "gauge",
     "measur",
     "hamper",
     "nominat",
-    "assur",
+    "assure",
     "merge",
     "achieve",
     "retain",
@@ -1045,7 +1038,7 @@ fuzzable_names += [
     "grapple",
     "appropriat",
     "stifle",
-    "notic",
+    "notice",
     "document",
     "migrate",
     "color",
